<?php

namespace Drupal\smartlinker_ai\Service;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Site\Settings;

/**
 * Service to retrieve OpenAI API key securely.
 */
class OpenAiKeyService {

  /**
   * The config factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected ConfigFactoryInterface $configFactory;


  /**
   * The settings.
   */
  protected Settings $settings;

  /**
   * Constructs a new OpenAiKeyService object.
   */
  public function __construct(ConfigFactoryInterface $configFactory, Settings $settings) {
    $this->configFactory = $configFactory;
    $this->settings = $settings;
  }

  /**
   * Get the OpenAI API key.
   */
  public function getOpenApiKey() {
    $config = $this->configFactory->get('ai_provider_openai.settings');
    $api_key = $config->get('api_key');

    $key_config = $this->configFactory->get('key.key.' . $api_key);
    $provider = $key_config->get('key_provider');

    if ($provider == 'file') {
      $file_name = $key_config->get('key_provider_settings')['file_location'];
      // Get the root path.
      $app_root = $this->settings->get('app.root');

      if (!$app_root) {
        $app_root = getcwd();
      }

      // Ensure correct path format.
      $filepath = realpath($app_root . '/' . $file_name);
      if ($filepath && file_exists($filepath)) {
        return trim(file_get_contents($filepath));
      }
    }
    elseif ($provider == 'config') {
      return $key_config->get('key_provider_settings')['key_value'];
    }

    return NULL;
  }

}
